@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2001 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 2000-2002 Sendmail, Inc. and its suppliers.
  *	All rights reserved.
  *
  * By using this file, you agree to the terms and conditions set
@@ -8,7 +8,7 @@
  */
 
 #include <sm/gen.h>
-SM_IDSTR(id, "@(#)$Id: t-fopen.c,v 1.8 2001/09/11 04:04:49 gshapiro Exp $")
+SM_IDSTR(id, "@(#)$Id: t-fopen.c,v 1.9 2002/02/06 23:57:45 ca Exp $")
 
 #include <fcntl.h>
 #include <sm/io.h>
@@ -20,6 +20,7 @@ main(argc, argv)
 	int argc;
 	char *argv[];
 {
+	int m, r;
 	SM_FILE_T *out;
 
 	sm_test_begin(argc, argv, "test sm_io_fopen");
@@ -28,6 +29,9 @@ main(argc, argv)
 	if (out != NULL)
 	{
 		(void) sm_io_fprintf(out, SM_TIME_DEFAULT, "foo\n");
+		r = sm_io_getinfo(out, SM_IO_WHAT_MODE, &m);
+		SM_TEST(r == 0);
+		SM_TEST(m == SM_IO_WRONLY);
 		sm_io_close(out, SM_TIME_DEFAULT);
 	}
 	return sm_test_end();
