@@ -13,7 +13,7 @@
 
 #include <sendmail.h>
 
-SM_RCSID("@(#)$Id: envelope.c,v 8.294 2005/02/16 23:38:51 ca Exp $")
+SM_RCSID("@(#)$Id: envelope.c,v 8.296 2006/03/31 18:53:50 ca Exp $")
 
 /*
 **  CLRSESSENVELOPE -- clear session oriented data in an envelope
@@ -75,6 +75,10 @@ newenvelope(e, parent, rpool)
 	register ENVELOPE *parent;
 	SM_RPOOL_T *rpool;
 {
+#if _FFR_DM_PER_DAEMON
+	int		sendmode;
+#endif /* _FFR_DM_PER_DAEMON */
+
 	/*
 	**  This code used to read:
 	**	if (e == parent && e->e_parent != NULL)
@@ -84,6 +88,13 @@ newenvelope(e, parent, rpool)
 	**  This meant macvalue() could go into an infinite loop.
 	*/
 
+#if _FFR_DM_PER_DAEMON
+	if (parent != NULL)
+		sendmode = parent->e_sendmode;
+	else
+		sendmode = DM_NOTSET;
+#endif /* _FFR_DM_PER_DAEMON */
+
 	if (e == parent)
 		parent = e->e_parent;
 	clearenvelope(e, true, rpool);
@@ -119,6 +130,10 @@ newenvelope(e, parent, rpool)
 	e->e_putbody = putbody;
 	if (CurEnv->e_xfp != NULL)
 		(void) sm_io_flush(CurEnv->e_xfp, SM_TIME_DEFAULT);
+#if _FFR_DM_PER_DAEMON
+	if (sendmode != DM_NOTSET)
+		e->e_sendmode = sendmode;
+#endif /* _FFR_DM_PER_DAEMON */
 
 	return e;
 }
@@ -504,7 +519,14 @@ simpledrop:
 			printenvflags(e);
 		}
 		if (!panic)
+		{
+			if (e->e_dfp != NULL)
+			{
+				(void) sm_io_close(e->e_dfp, SM_TIME_DEFAULT);
+				e->e_dfp = NULL;
+			}
 			(void) xunlink(queuename(e, DATAFL_LETTER));
+		}
 		if (panic && QueueMode == QM_LOST)
 		{
 			/*
